@@ -2,7 +2,7 @@ package File::Edit;
 use Mojo::Base -base;
 use Path::Tiny qw/path/;
 use Carp;
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 has 'file';
 has 'found';        # Line numbers of found lines. ArrayRef.
@@ -95,7 +95,7 @@ sub _find_one {
     $o->_line_re($line_re);
 
     foreach my $l (@{$o->_lines}) {
-        push @{$o->found}, $n if $l =~ /\s*$line_re\s*/;
+        push @{$o->found}, $n if $l =~ $line_re;
         $n++;
     }
 
@@ -129,7 +129,7 @@ File::Edit - A naive, probably buggy, file editor.
 
 =head1 VERSION
 
-Version 0.0.2
+Version 0.0.3
 
 =cut
 =head1 SYNOPSIS
